@@ -356,8 +356,15 @@ thunar_thumbnailer_queue_async_reply (GObject      *proxy,
     }
   else if (error == NULL)
     {
-      /* store the handle returned by tumbler */
-      job->handle = handle;
+      if (handle == 0)
+        {
+          g_printerr ("ThunarThumbnailer: got 0 handle (Queue)\n");
+        }
+      else
+        {
+          /* store the handle returned by tumbler */
+          job->handle = handle;
+        }
     }
   else
     {
@@ -871,6 +878,12 @@ thunar_thumbnailer_thumbnailer_finished (GDBusProxy        *proxy,
   _thunar_return_if_fail (G_IS_DBUS_PROXY (proxy));
   _thunar_return_if_fail (THUNAR_IS_THUMBNAILER (thumbnailer));
 
+  if (handle == 0)
+    {
+      g_printerr ("ThunarThumbnailer: got 0 handle (Finished)\n");
+      return;
+    }
+
   _thumbnailer_lock (thumbnailer);
 
   for (lp = thumbnailer->jobs; lp != NULL; lp = lp->next)
@@ -912,6 +925,12 @@ thunar_thumbnailer_idle (ThunarThumbnailer          *thumbnailer,
   if (G_UNLIKELY (uris == NULL))
     return;
 
+  if (handle == 0)
+    {
+      g_printerr ("ThunarThumbnailer: got 0 handle (Error or Ready)\n");
+      return;
+    }
+
   _thumbnailer_lock (thumbnailer);
 
   /* look for the job so we don't emit unknown handles, the reason
